@@ -2,12 +2,13 @@ import click
 
 from .. import __version__
 
+from .assignments import assignments
 from .cfn import generate_template
 from .configure_profile import configure_profile
 from .credential_process import credential_process
+from .deploy_macro import deploy_macro
 from .populate_profiles import populate_profiles
 from .lookup import lookup
-from .assignments import assignments
 
 @click.group(name="aws-sso-util")
 @click.version_option(version=__version__, message='%(version)s')
@@ -24,6 +25,7 @@ configure.add_command(populate_profiles, "populate")
 cli.add_command(lookup)
 cli.add_command(assignments)
 
+# cli.add_command(deploy_macro)
 cli.add_command(generate_template, "cfn")
 
 cli.add_command(credential_process)
